import numpy as np


def model(X):
    """returns the value of the limit state function Y of the
    strength of a short, square (5x15) steel column subjected to an axial
    load and a bending moment. The problem is described by 3 variables given
    in X = [Y, M, P].

    Parameters
    ----------
    X: ndarray
        3-column matrix
        x[:,0]: yield stress    (MPa)
        x[:,1]: bending moment  (Nmm)
        x[:,2]: axial force     (N)        
    
    Returns
    -------
    1darray
        Y: strength of a steel column

    For more info, see: http://www.sfu.ca/~ssurjano/shortcol.html
    """
    X = np.array(X,ndmin=2)
    Y = X[:, 0]; # yield stress    (MPa)
    M = X[:, 1]; # bending moment  (Nmm)
    P = X[:, 2]; # axial force     (N)
    
    # define cross-section width and depth
    b = 5
    h = 15

    # Calculate the single terms:
    term1 = -4*M / (b*(h**2)*Y)
    term2 = -(P**2) / ((b**2)*(h**2)*(Y**2))
    Y = 1 + term1 + term2
   
    return Y
